@@ -17,7 +17,7 @@ class BoxLog:
             'critical': logging.critical
         }
         level = 'info' if level not in levels else level
-        if self.print2log:
+        if self.print:
             print(f'{level.upper()}: {msg}')
         else:
             log = levels[level]
